﻿------------------------------------------------------
------------------------------------------------------
--
-- Totem Functions v 1.0
--
-- by Vardelm
--
------------------------------------------------------
------------------------------------------------------


--------------------------------------
-- Call of the Elements slash command
--------------------------------------
SLASH_TFSETCOE1 = "/setcoe"
function TF_SetCallOfElements(args)
	
	-- Parse the args
	fireTotem, earthTotem, waterTotem, airTotem = TF_ParseTotemArgs(args)
	
	-- Set Call of the Elements
	TF_SetCall("Call of the Elements", fireTotem, earthTotem, waterTotem, airTotem)
end
SlashCmdList["TFSETCOE"] = TF_SetCallOfElements



--------------------------------------
-- Call of the Ancestors slash command
--------------------------------------
SLASH_TFSETCOA1 = "/setcoa"
function TF_SetCallOfAncestors(fireTotem, earthTotem, waterTotem, airTotem)
	
	-- Parse the args
	fireTotem, earthTotem, waterTotem, airTotem = TF_ParseTotemArgs(args)
	
	-- Set Call of the Ancestors
	TF_SetCall("Call of the Ancestors", fireTotem, earthTotem, waterTotem, airTotem)
end
SlashCmdList["TFSETCOA"] = TF_SetCallOfAncestors



--------------------------------------
-- Call of the Spirits slash command
--------------------------------------
SLASH_TFSETCOS1 = "/setcos"
function TF_SetCallOfSpirits(fireTotem, earthTotem, waterTotem, airTotem)
	
	-- Parse the args
	fireTotem, earthTotem, waterTotem, airTotem = TF_ParseTotemArgs(args)
	
	-- Set Call of the Spirits
	TF_SetCall("Call of the Spirits", fireTotem, earthTotem, waterTotem, airTotem)
end
SlashCmdList["TFSETCOS"] = TF_SetCallOfSpirits





--------------------------------------
-- ParseTotemArgs
-- Takes the arguments from the slash
-- commands and parses them into the
-- separate totems
--------------------------------------
function TF_ParseTotemArgs(args)
	
	-- Split the args string using comma "," as delimiter
	fireTotem, earthTotem, waterTotem, airTotem = strsplit(",", args, 4)
	
	-- Trim the spaces off beginning & end of strings
	fireTotem = strtrim(fireTotem)
	earthTotem = strtrim(earthTotem)
	waterTotem = strtrim(waterTotem)
	airTotem = strtrim(airTotem)
	
	-- Return the values
	return fireTotem, earthTotem, waterTotem, airTotem
end



--------------------------------------
-- GetTotemID
-- Finds the spellID of a given totem.
-- Can take abbreviations as input.
--------------------------------------
function TF_GetTotemID(callActionSlot, totemSpell)

	-- variable to hold the totem's full name
	local totemSpellName

	-- Set totemSpellName if abbreviations are used
	if (totemSpell == "ct") then
		totemSpellName = "Cleansing Totem"
	
	elseif (totemSpell == "eb") then
		totemSpellName = "Earthbind Totem"
	
	elseif (totemSpell == "ee") then
		totemSpellName = "Earth Elemental Totem"
	
	elseif (totemSpell == "fe") then
		totemSpellName = "Fire Elemental Totem"

	elseif (totemSpell == "fr") then
		totemSpellName = "Fire Resistance Totem"
	
	
	elseif (totemSpell == "fs") then
		totemSpellName = "Frost Resistance Totem"

	elseif (totemSpell == "ft") then
		totemSpellName = "Flametongue Totem"

	elseif (totemSpell == "gt") then
		totemSpellName = "Grounding Totem"

	elseif (totemSpell == "hs") then
		totemSpellName = "Healing Stream Totem"

	elseif (totemSpell == "mn") then
		totemSpellName = "Mana Tide Totem"
	

	elseif (totemSpell == "ms") then
		totemSpellName = "Mana Spring Totem"

	elseif (totemSpell == "mt") then
		totemSpellName = "Magma Totem"
	
	elseif (totemSpell == "nr") then
		totemSpellName = "Nature Resistance Totem"

	elseif (totemSpell == "sc") then
		totemSpellName = "Stoneclaw Totem"

	elseif (totemSpell == "se") then
		totemSpellName = "Strength of Earth Totem"
	

	elseif (totemSpell == "sn") then
		totemSpellName = "Sentry Totem"

	elseif (totemSpell == "ss") then
		totemSpellName = "Stoneskin Totem"
	
	elseif (totemSpell == "st") then
		totemSpellName = "Searing Totem"

	elseif (totemSpell == "tt") then
		totemSpellName = "Tremor Totem"

	elseif (totemSpell == "wa") then
		totemSpellName = "Wrath of Air Totem"


	elseif (totemSpell == "wf") then
		totemSpellName = "Windfury Totem"

	elseif (totemSpell == "wt") then
		totemSpellName = "Wrath Totem"

	-- If none of the abbreviations specified above are used, then
	-- just set totemSpellName to the name specified
	else
		totemSpellName = totemSpell
	end


	-- Get the spellIDs of valid spells for  the totem action slot
	-- Apparently returns the highest rank totem (convenient!)
	tot1, tot2, tot3, tot4, tot5, tot6, tot7 = GetMultiCastTotemSpells(callActionSlot)
	
	-- Check if totemSpellName matches name of one of the valid spells
	-- If it does match, return the spellID found above
	if (tot1 and (totemSpellName == (GetSpellInfo(tot1)) ) ) then
		return tot1
	elseif (tot2 and (totemSpellName == (GetSpellInfo(tot2)) ) ) then
		return tot2
	elseif (tot3 and (totemSpellName == (GetSpellInfo(tot3)) ) ) then
		return tot3
	elseif (tot4 and (totemSpellName == (GetSpellInfo(tot4)) ) ) then
		return tot4
	elseif (tot5 and (totemSpellName == (GetSpellInfo(tot5)) ) ) then
		return tot5
	elseif (tot6 and (totemSpellName == (GetSpellInfo(tot6)) ) ) then
		return tot6
	elseif (tot7 and (totemSpellName == (GetSpellInfo(tot7)) ) ) then
		return tot7
	end
end
	


--------------------------------------
-- SetCall
-- Sets the specified totem "Call of"
-- spell with the given totems.
--------------------------------------
function TF_SetCall(callSpell, fireTotem, earthTotem, waterTotem, airTotem)
	
	-- Set the Call action slot values based on the Call spell
	local fireActionID
	local earthActionID
	local waterActionID
	local airActionID
	
	if (callSpell == "Call of the Elements") then
		fireActionID = 133
		earthActionID = 134
		waterActionID = 135
		airActionID = 136
	elseif (callSpell == "Call of the Ancestors") then
		fireActionID = 137
		earthActionID = 138
		waterActionID = 139
		airActionID = 140
	elseif (callSpell == "Call of the Spirits") then
		fireActionID = 141
		earthActionID = 142
		waterActionID = 143
		airActionID = 144
	end
	
	-- Find & set the totem spellIDs
	local fireTotemID = TF_GetTotemID(fireActionID, fireTotem)
	local earthTotemID = TF_GetTotemID(earthActionID, earthTotem)
	local waterTotemID = TF_GetTotemID(waterActionID, waterTotem)
	local airTotemID = TF_GetTotemID(airActionID, airTotem)

	-- Set the Call spell with the totems
	SetMultiCastSpell(fireActionID, fireTotemID)
	SetMultiCastSpell(earthActionID, earthTotemID)
	SetMultiCastSpell(waterActionID, waterTotemID)
	SetMultiCastSpell(airActionID, airTotemID)
	
end


